@@ -3,6 +3,7 @@ from typing import Any
 
 from meiga import Result, Error, Failure, Success
 
+from petisco.domain.entities.value_object import ValueObject
 from petisco.domain.errors.given_input_is_not_valid_error import (
     GivenInputIsNotValidError,
 )
@@ -11,7 +12,7 @@ from petisco.domain.errors.input_exceed_lenght_limit_error import (
 )
 
 
-class ClientId(str):
+class ClientId(str, ValueObject):
     def __new__(cls, client_id, length: int = 50):
         client_id = None if client_id == "None" else client_id
         cls.length = length
