@@ -1,3 +1,4 @@
+import json
 from typing import Tuple, Dict
 
 from petisco.events.event import Event
@@ -11,16 +12,18 @@ REQUEST_RESPONDED_UNWRAP_ERROR = (
     },
 )
 
+REQUEST_RESPONDED_VERSION = "1.1.0"
+
 
 class RequestResponded(Event):
     application: str
     controller: str
     is_success: bool
-    status_code: int
-    content: dict
+    http_response: Dict
     correlation_id: str
     elapsed_time: float
     additional_info: Dict[str, str]
+    version: str = None
 
     def __init__(
         self,
@@ -31,6 +34,7 @@ class RequestResponded(Event):
         correlation_id: str,
         elapsed_time: float,
         additional_info: Dict[str, str],
+        version: str = REQUEST_RESPONDED_VERSION,
     ):
         self.application = application
         self.controller = controller
@@ -38,25 +42,27 @@ class RequestResponded(Event):
         self.correlation_id = correlation_id
         self.elapsed_time = elapsed_time
         self.additional_info = additional_info
-        self.set_content_and_status_code(http_response)
-
+        self.set_http_response(http_response)
+        self.version = version
         super().__init__()
 
-    def set_content_and_status_code(self, http_response):
-        content = REQUEST_RESPONDED_UNWRAP_ERROR
-        status_code = 500
+    def set_http_response(self, http_response):
+        _http_response = {
+            "content": json.dumps(REQUEST_RESPONDED_UNWRAP_ERROR),
+            "status_code": 500,
+        }
         if isinstance(http_response, Tuple):
-            content = http_response[0]
-            status_code = http_response[1]
+            _http_response["content"] = json.dumps(http_response[0])
+            _http_response["status_code"] = http_response[1]
         else:
             try:
                 from flask import Response
 
                 if isinstance(http_response, Response):
-                    content = "binary"
-                    status_code = http_response.status_code
+                    _http_response["content"] = "flask response (multipart)"
+                    _http_response["status_code"] = http_response.status_code
+
             except (RuntimeError, ImportError):
                 pass
 
-        self.content = content
-        self.status_code = status_code
+        self.http_response = _http_response
